# zenyxvm
The zenyx version manager package

## Requirements
- Make sure you have a `pyproject.toml` file in your project's root folder
- Use python 3.7 or newer

## How to use?
Run the manager:
- Windows:
```bash
python -m zenyxvm
```

- Linux:
```bash
python3 -m zenyxvm
```